@@ -29,6 +29,7 @@
 #include "wx/radiobox.h"
 
 #include "wx/wxhtml.h"
+#include "wx/odcombo.h"
 
 #include "certtree.h"
 
@@ -109,7 +110,7 @@ class CRQ_ProviderPage : public CRQ_Page {
 	void DoUpdateInfo();
 	void UpdateInfo(wxCommandEvent&);
 	vector<TQSL_PROVIDER> providers;
-	wxComboBox *tc_provider;
+	wxOwnerDrawnComboBox *tc_provider;
 	wxStaticText *tc_provider_info;
 
 	DECLARE_EVENT_TABLE()
@@ -124,8 +125,8 @@ class CRQ_CallsignPage : public CRQ_Page {
 	virtual CRQ_Page *GetNext() const;
  private:
 	wxTextCtrl *tc_call;
-	wxComboBox *tc_qsobeginy, *tc_qsobeginm, *tc_qsobegind, *tc_dxcc;
-	wxComboBox *tc_qsoendy, *tc_qsoendm, *tc_qsoendd;
+	wxOwnerDrawnComboBox *tc_qsobeginy, *tc_qsobeginm, *tc_qsobegind, *tc_dxcc;
+	wxOwnerDrawnComboBox *tc_qsoendy, *tc_qsoendm, *tc_qsoendd;
 	wxStaticText *tc_status;
 	bool initialized;		// Set true when validating makes sense
 	int em_w;
