@@ -197,7 +197,7 @@ int SaveAddressInfo(const char *callsign, int dxcc);
 
 class LocPropDial : public wxDialog {
  public:
-        explicit LocPropDial(wxString locname, bool display, wxWindow *parent = 0);
+        explicit LocPropDial(wxString locname, bool display, const char *filename = NULL, wxWindow *parent = 0);
         void closeMe(wxCommandEvent&) { EndModal(wxID_OK); }
         DECLARE_EVENT_TABLE()
 };
